linchpin module
===============

The linchpin module contains calls to implement the Command Line
Interface within linchpin. It uses the `Click <http://click.pocoo.org>`_
command line interface composer.

.. automodule:: linchpin
    :members:
    :undoc-members:
    :exclude-members: main,runcli

.. autofunction:: init
.. autofunction:: up
.. autofunction:: destroy
